WfEpy
=====

**Workflow Engine for Python**


Installation
------------

Install it using pip ::

    pip3 install wfepy

or clone repository ::

    git clone https://gitlab.com/redhat-aqe/wfepy.git
    cd wfepy

and install Python package including dependencies ::

    python3 setup.py install
